%% STRIPES
% 2-D
% Parameters
c = 1; % Fourier coeffecient
k = 2;   % wavenumber
n = 2;   % order

% Range for x and y
x = linspace(-2, 2, 500);
y = linspace(-2, 2, 500);

% Create a meshgrid for 2D
[~, Y] = meshgrid(x, y);

% Define the 2D function
f_xy = (1 + (c * cos(n * k * Y))) / (1 + (0.5 * c^2));

% Plot the 2D image using imagesc
figure(1);
imagesc(x, y, f_xy);
axis xy; % Make sure the y-axis is oriented correctly
colorbar;
xlabel('$x l_o$', 'Interpreter', 'latex', 'FontSize', 14)
ylabel('$y l_o$', 'Interpreter', 'latex', 'FontSize', 14)
title('Stripe Lattice ansatz for $|\Psi(x,y)|^2$', 'Interpreter', 'latex', 'FontSize', 16);
xlabel('x');
ylabel('y');
colormap parula;

%% TRIANGULAR LATTICE
% 2-D
% Parameters
c1 = 0.2; 
c2 = 0.2; 
k  = 3;   
n  = 1;   

% Range for x and y
x = linspace(-2, 2, 500);
y = linspace(-2, 2, 500);

% Create a meshgrid for 2D
[X, Y] = meshgrid(x, y);

% Define the 2D function for a triangular lattice
f_xy = 1 + (c1 * cos(n * k * (2/sqrt(3)) * Y)) + (2 * c2 * cos(n * k * (1/sqrt(3)) * Y) .* cos(n * k * X));

% Plot the 2D image using imagesc
figure(2);
clf
imagesc(x, y, f_xy);
axis xy; % Make sure the y-axis is oriented correctly
colorbar;
xlabel('$x l_o$', 'Interpreter', 'latex', 'FontSize', 14)
ylabel('$y l_o$', 'Interpreter', 'latex', 'FontSize', 14)
title('Triangular Lattice ansatz for $|\Psi(x,y)|^2$', 'Interpreter', 'latex', 'FontSize', 16);
xlabel('x');
ylabel('y');
colormap parula;

%% HONEYCOMB LATTICE
% 2-D
% Parameters
c1 = 0.2; 
c2 = 0.2; 
k  = 3;   
n  = 1;   

% Range for x and y
x = linspace(-2, 2, 500);
y = linspace(-2, 2, 500);

% Create a meshgrid for 2D
[X, Y] = meshgrid(x, y);

% Define the 2D function for a honeycomb lattice
f_xy = 1 - (c1 * cos(n * k * (2/sqrt(3)) * X)) - (2 * c2 * cos(n * k * (1/sqrt(3)) * X) .* cos(n * k * Y));

% Plot the 2D image using imagesc
figure(3);
clf
imagesc(x, y, f_xy);
axis xy; % Make sure the y-axis is oriented correctly
colorbar;
xlabel('$x l_o$', 'Interpreter', 'latex', 'FontSize', 14)
ylabel('$y l_o$', 'Interpreter', 'latex', 'FontSize', 14)
title('Honeycomb Lattice ansatz for $|\Psi(x,y)|^2$', 'Interpreter', 'latex', 'FontSize', 16);
xlabel('x');
ylabel('y');
colormap parula;
